<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>GuidelineEditDialog</name>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
        <source>Edit guideline...</source>
        <translation>Posició d&apos;edició...</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
        <source>Page:</source>
        <translation>Pàgina:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
        <source>Position:</source>
        <translation>Posició:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
        <source>cm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
        <source>in</source>
        <translation>in (polsades)</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
        <source>bp</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PaperSize</name>
    <message>
        <location filename="../src/PaperSizes.cpp" line="24"/>
        <source>Beamer 16:10</source>
        <translation>Pantalla 16:10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="25"/>
        <source>Beamer 16:9</source>
        <translation>Pantalla 16:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="26"/>
        <source>Beamer 14:9</source>
        <translation>Pantalla 14:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="27"/>
        <source>Beamer 1.41:1</source>
        <translation>Pantalla 1.41:1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="28"/>
        <source>Beamer 5:4</source>
        <translation>Pantalla 5:4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="29"/>
        <source>Beamer 4:3</source>
        <translation>Pantalla 4:3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="30"/>
        <source>Beamer 3:2</source>
        <translation>Pantalla 3:2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="33"/>
        <source>Screen</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="36"/>
        <source>DIN 4A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="37"/>
        <source>DIN 2A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="38"/>
        <source>DIN A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="39"/>
        <source>DIN A1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="40"/>
        <source>DIN A2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="41"/>
        <source>DIN A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="42"/>
        <source>DIN A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="43"/>
        <source>DIN A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="44"/>
        <source>DIN A6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="45"/>
        <source>DIN A7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="46"/>
        <source>DIN A8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="47"/>
        <source>DIN A9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="48"/>
        <source>DIN A10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="49"/>
        <source>DIN B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="50"/>
        <source>DIN B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="51"/>
        <source>DIN B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="52"/>
        <source>DIN B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="53"/>
        <source>DIN B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="54"/>
        <source>DIN B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="55"/>
        <source>DIN B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="56"/>
        <source>DIN B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="57"/>
        <source>DIN B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="58"/>
        <source>DIN B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="59"/>
        <source>DIN B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="60"/>
        <source>DIN C0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="61"/>
        <source>DIN C1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="62"/>
        <source>DIN C2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="63"/>
        <source>DIN C3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="64"/>
        <source>DIN C4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="65"/>
        <source>DIN C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="66"/>
        <source>DIN C6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="67"/>
        <source>DIN C7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="68"/>
        <source>DIN C8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="69"/>
        <source>DIN C9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="70"/>
        <source>DIN C10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="71"/>
        <source>DIN DL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="72"/>
        <source>DIN DLE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="73"/>
        <source>DIN C6/C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="74"/>
        <source>DIN RA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="75"/>
        <source>DIN RA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="76"/>
        <source>DIN RA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="77"/>
        <source>DIN RA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="78"/>
        <source>DIN RA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="79"/>
        <source>DIN SRA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="80"/>
        <source>DIN SRA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="81"/>
        <source>DIN SRA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="82"/>
        <source>DIN SRA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="83"/>
        <source>DIN SRA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="84"/>
        <source>SIS D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="85"/>
        <source>SIS D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="86"/>
        <source>SIS D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="87"/>
        <source>SIS D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="88"/>
        <source>SIS D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="89"/>
        <source>SIS D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="90"/>
        <source>SIS D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="91"/>
        <source>SIS D7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="92"/>
        <source>SIS D8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="93"/>
        <source>SIS D9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="94"/>
        <source>SIS E0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="95"/>
        <source>SIS E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="96"/>
        <source>SIS E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="97"/>
        <source>SIS E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="98"/>
        <source>SIS E4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="99"/>
        <source>SIS E5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="100"/>
        <source>SIS E6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="101"/>
        <source>SIS E7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="102"/>
        <source>SIS E8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="103"/>
        <source>SIS E9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="104"/>
        <source>SIS F0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="105"/>
        <source>SIS F1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="106"/>
        <source>SIS F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="107"/>
        <source>SIS F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="108"/>
        <source>SIS F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="109"/>
        <source>SIS F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="110"/>
        <source>SIS F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="111"/>
        <source>SIS F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="112"/>
        <source>SIS F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="113"/>
        <source>SIS F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="114"/>
        <source>SIS G0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="115"/>
        <source>SIS G1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="116"/>
        <source>SIS G2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="117"/>
        <source>SIS G3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="118"/>
        <source>SIS G4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="119"/>
        <source>SIS G5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="120"/>
        <source>SIS G6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="121"/>
        <source>SIS G7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="122"/>
        <source>SIS G8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="123"/>
        <source>SIS G9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="124"/>
        <source>JIS B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="125"/>
        <source>JIS B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="126"/>
        <source>JIS B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="127"/>
        <source>JIS B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="128"/>
        <source>JIS B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="129"/>
        <source>JIS B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="130"/>
        <source>JIS B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="131"/>
        <source>JIS B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="132"/>
        <source>JIS B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="133"/>
        <source>JIS B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="134"/>
        <source>JIS B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="135"/>
        <source>JIS B11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="136"/>
        <source>JIS B12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="137"/>
        <source>JIS Shiroku ban 4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="138"/>
        <source>JIS Shiroku ban 5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="139"/>
        <source>JIS Shiroku ban 6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="140"/>
        <source>JIS Kiku 4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="141"/>
        <source>JIS Kiku 5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="142"/>
        <source>SAC D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="143"/>
        <source>SAC D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="144"/>
        <source>SAC D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="145"/>
        <source>SAC D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="146"/>
        <source>SAC D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="147"/>
        <source>SAC D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="148"/>
        <source>SAC D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="150"/>
        <source>Letter (ANSI A)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="151"/>
        <source>Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="152"/>
        <source>Tabloid (ANSI B)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="153"/>
        <source>Ledger</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="154"/>
        <source>Junior Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="155"/>
        <source>Half Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="156"/>
        <source>Government Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="157"/>
        <source>Government Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="158"/>
        <source>ANSI C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="159"/>
        <source>ANSI D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="160"/>
        <source>ANSI E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="161"/>
        <source>Arch A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="162"/>
        <source>Arch B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="163"/>
        <source>Arch C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="164"/>
        <source>Arch D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="165"/>
        <source>Arch E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="166"/>
        <source>Arch E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="167"/>
        <source>Arch E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="168"/>
        <source>Arch E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="201"/>
        <source>mm</source>
        <extracomment>Length unit: millimeters</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="207"/>
        <source>in</source>
        <extracomment>Length unit: inches</extracomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPDF</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="33"/>
        <source>[language name]</source>
        <translation>català</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="34"/>
        <source>[translator&apos;s name/email]</source>
        <translation>Ignasi Furió</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <location filename="../src/PDFBackend.cpp" line="321"/>
        <source>rendering page</source>
        <translation>pàgina en construcció</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
        <source>Unlock PDF</source>
        <translation>Desbloqueja PDF</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
        <source>Please enter the password to unlock the PDF</source>
        <translation>Si us plau, introdueixi la contrassenya per desbloquejar el PDF</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>Incorrect password</source>
        <translation>Contrassenya incorrecta</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>The password you entered was incorrect.</source>
        <translation>La contrassenya introduida és incorrecta.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
        <source>This document is locked. You need a password to open it.</source>
        <translation>El document està bloquejat. Cal una contrassenya per obrir-lo.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2036"/>
        <source>Unlock</source>
        <translation>Desbloquejar</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Insufficient permission</source>
        <translation>Permisos insuficients</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Text extraction is not allowed for this document.</source>
        <translation>No està permès extreure el text d&apos;aquest document.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2577"/>
        <source>Goto page %1</source>
        <translation>Ves a pàgina %1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2589"/>
        <source>Execute `%1`</source>
        <translation>Executa `%1`</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2835"/>
        <location filename="../src/PDFDocumentView.cpp" line="2852"/>
        <source>Table of Contents</source>
        <translation>Taula de continguts</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2944"/>
        <location filename="../src/PDFDocumentView.cpp" line="3151"/>
        <source>Meta Data</source>
        <translation>Meta dades</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3000"/>
        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
        <source>Processing</source>
        <translation>Processant</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3032"/>
        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3057"/>
        <source>B</source>
        <extracomment>File size: bytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3059"/>
        <source>kB</source>
        <extracomment>File size: kilobytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3061"/>
        <source>MB</source>
        <extracomment>File size: megabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3063"/>
        <source>GB</source>
        <extracomment>File size: gigabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3065"/>
        <source>TB</source>
        <extracomment>File size: terabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3095"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3098"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3101"/>
        <location filename="../src/PDFDocumentView.cpp" line="3138"/>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3153"/>
        <source>Document</source>
        <translation>Document</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3154"/>
        <source>Title:</source>
        <translation>Títol:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3155"/>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3156"/>
        <source>Subject:</source>
        <translation>Assumpte:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3157"/>
        <source>Keywords:</source>
        <translation>Paraules clau:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
        <source>Page size:</source>
        <translation>Mida pàgina:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3159"/>
        <source>File size:</source>
        <translation>Mida Fitxer:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3162"/>
        <source>Creator:</source>
        <translation>Creador:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
        <source>Producer:</source>
        <translation>Productor:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
        <source>Creation date:</source>
        <translation>Data de creació:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
        <source>Modification date:</source>
        <translation>Data de modificació:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
        <source>Trapped:</source>
        <translation>Atrapat:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
        <location filename="../src/PDFDocumentView.cpp" line="3271"/>
        <source>Fonts</source>
        <translation>Fonts</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3227"/>
        <source>Type 0</source>
        <translation>Tipus 0</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3230"/>
        <source>Type 1</source>
        <translation>Tipus 1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3233"/>
        <source>Type 1 (multiple master)</source>
        <translation>Tipus 1 (màster múltiple)</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3236"/>
        <source>Type 3</source>
        <translation>Tipus 3</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3239"/>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
        <source>yes</source>
        <translation>sí</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
        <source>no</source>
        <translation>no</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3245"/>
        <source>[embedded]</source>
        <translation>[incrustat]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3248"/>
        <source>[builtin]</source>
        <translation>[order interna]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Subset</source>
        <translation>Subconjunt</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3280"/>
        <location filename="../src/PDFDocumentView.cpp" line="3375"/>
        <source>Permissions</source>
        <translation>Permisos</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3329"/>
        <location filename="../src/PDFDocumentView.cpp" line="3338"/>
        <location filename="../src/PDFDocumentView.cpp" line="3347"/>
        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
        <source>Allowed</source>
        <translation>Permés</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3331"/>
        <source>Low resolution only</source>
        <translation>Només baixa resolució</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3334"/>
        <location filename="../src/PDFDocumentView.cpp" line="3344"/>
        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
        <location filename="../src/PDFDocumentView.cpp" line="3356"/>
        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
        <location filename="../src/PDFDocumentView.cpp" line="3366"/>
        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
        <location filename="../src/PDFDocumentView.cpp" line="3368"/>
        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
        <location filename="../src/PDFDocumentView.cpp" line="3370"/>
        <source>Denied</source>
        <translation>Denegat</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3340"/>
        <source>Assembling only</source>
        <translation>Només assemblat</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Inserir, rotar o eliminar pàgines i crear marcadors o miniatures</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
        <source>Accessibility support only</source>
        <translation>Només suport d&apos;accesibilitat</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
        <source>Printing:</source>
        <translation>Impressió:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
        <source>Modifications:</source>
        <translation>Modificacions:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
        <source>Extraction:</source>
        <translation>Extracció:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
        <source>Annotation:</source>
        <translation>Anotació:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
        <source>Filling forms:</source>
        <translation>Formularis:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
        <location filename="../src/PDFDocumentView.cpp" line="3481"/>
        <source>Annotations</source>
        <translation>Anotacions</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Subject</source>
        <translation>Assumpte</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Contents</source>
        <translation>Continguts</translation>
    </message>
</context>
</TS>
